______________________________________________________________________

name: Bug report about: Bug reports help us improve! Thanks for submitting yours! title: "[BUG] "
labels: bug assignees: ''

______________________________________________________________________

## Expected Behavior

Tell us what should happen

## Actual Behavior

Tell us what happens instead

## Example Code

Please see
[How to create a Minimal, Reproducible example](https://stackoverflow.com/help/minimal-reproducible-example)
for some guidance on creating the best possible example of the problem

```bash

```

## Dataset Description

Please tell us about the shape and datatype of your data, (e.g. 128 dimensions, 12.3 billion points,
floats)

- Dimensions:
- Number of Points:
- Data type:

## Error

```
Paste the full error, with any sensitive information minimally redacted and marked $$REDACTED$$

```

## Your Environment

- Operating system (e.g. Windows 11 Pro, Ubuntu 22.04.1 LTS)
- DiskANN version (or commit built from)

## Additional Details

Any other contextual information you might feel is important.
